/*
* Copyright (c) 2005-2006 Compuware Corporation and others.
* All rights reserved. This program and the accompanying
* materials are made available under the terms of the
* Eclipse Public License v1.0 which accompanies this
* distribution, and is available at:
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*     Compuware Corporation - initial API and implementation
*
*/

package org.apache.muse.core.platform.osgi.mini.internal;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.Principal;
import java.util.Enumeration;
import java.util.Locale;
import java.util.Map;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletInputStream;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

public class RequestWrapper implements HttpServletRequest {

	HttpServletRequest wrappedRequest;
	
	public RequestWrapper(HttpServletRequest request){
		this.wrappedRequest = request;
	}

	public String getAuthType() {
		return wrappedRequest.getAuthType();
	}

	public String getContextPath() {
		String servletPath = wrappedRequest.getServletPath();
		if(servletPath.endsWith("/services")){
			return servletPath.substring(0,servletPath.lastIndexOf("/services"));
		}
		return wrappedRequest.getContextPath();
	}

	public Cookie[] getCookies() {
		return wrappedRequest.getCookies();
	}

	public long getDateHeader(String arg0) {
		return wrappedRequest.getDateHeader(arg0);
	}

	public String getHeader(String arg0) {
		return wrappedRequest.getHeader(arg0);
	}

	public Enumeration getHeaderNames() {
		return wrappedRequest.getHeaderNames();
	}

	public Enumeration getHeaders(String arg0) {
		//TODO patch this one for sure.
		return wrappedRequest.getHeaders(arg0);
	}

	public int getIntHeader(String arg0) {
		return wrappedRequest.getIntHeader(arg0);
	}
    
    public String getLocalAddr() {
        return wrappedRequest.getLocalAddr();
    }
    
    public String getLocalName() {
        return wrappedRequest.getLocalName();
    }
    
    public int getLocalPort() {
        return wrappedRequest.getLocalPort();
    }

	public String getMethod() {
		return wrappedRequest.getMethod();
	}

	public String getPathInfo() {
		return wrappedRequest.getPathInfo();
	}

	public String getPathTranslated() {
		return wrappedRequest.getPathTranslated();
	}

	public String getQueryString() {
		return wrappedRequest.getQueryString();
	}

    public int getRemotePort() {
        return wrappedRequest.getRemotePort();
    }

	public String getRemoteUser() {
		return wrappedRequest.getRemoteUser();
	}

	public String getRequestURI() {
		return wrappedRequest.getRequestURI();
	}

	public StringBuffer getRequestURL() {
		String proto = "http";
		String uri  = wrappedRequest.getRequestURI();
		String protocol = wrappedRequest.getProtocol();
		String server = wrappedRequest.getServerName();
		int port = wrappedRequest.getServerPort();
		if(protocol.startsWith("HTTPS/")){
			proto = "https";
		}
		StringBuffer buffer = new StringBuffer();
		buffer.append(proto);
		buffer.append("://");
		buffer.append(server);
		if(port != 80){
			buffer.append(":");
			buffer.append(port);
		}
		buffer.append(uri);
		return buffer;
	}

	public String getRequestedSessionId() {
		return wrappedRequest.getRequestedSessionId();
	}

	public String getServletPath() {
		return wrappedRequest.getServletPath();
	}

	public HttpSession getSession() {
		return wrappedRequest.getSession();
	}

	public HttpSession getSession(boolean arg0) {
		return wrappedRequest.getSession(arg0);
	}

	public Principal getUserPrincipal() {
		//TODO patch this one for sure.
		return wrappedRequest.getUserPrincipal();
	}

	public boolean isRequestedSessionIdFromCookie() {
		return wrappedRequest.isRequestedSessionIdFromCookie();
	}

	public boolean isRequestedSessionIdFromURL() {
		return wrappedRequest.isRequestedSessionIdFromURL();
	}

	public boolean isRequestedSessionIdFromUrl() {
		return wrappedRequest.isRequestedSessionIdFromUrl();
	}

	public boolean isRequestedSessionIdValid() {
		return wrappedRequest.isRequestedSessionIdValid();
	}

	public boolean isUserInRole(String arg0) {
		//TODO patch this one for sure.
		return wrappedRequest.isUserInRole(arg0);
	}

	public Object getAttribute(String arg0) {
		return wrappedRequest.getAttribute(arg0);
	}

	public Enumeration getAttributeNames() {
		return wrappedRequest.getAttributeNames();
	}

	public String getCharacterEncoding() {
		return wrappedRequest.getCharacterEncoding();
	}

	public int getContentLength() {
		return wrappedRequest.getContentLength();
	}

	public String getContentType() {
		return wrappedRequest.getContentType();
	}

	public ServletInputStream getInputStream() throws IOException {
		return wrappedRequest.getInputStream();
	}

	public Locale getLocale() {
		//TODO patch this one for sure.
		return wrappedRequest.getLocale();
	}

	public Enumeration getLocales() {
		//TODO patch this one for sure.
		return wrappedRequest.getLocales();
	}

	public String getParameter(String arg0) {
		return wrappedRequest.getParameter(arg0);
	}

	public Map getParameterMap() {
		//TODO patch this one for sure.
		return wrappedRequest.getParameterMap();
	}

	public Enumeration getParameterNames() {
		return wrappedRequest.getParameterNames();
	}

	public String[] getParameterValues(String arg0) {
		return wrappedRequest.getParameterValues(arg0);
	}

	public String getProtocol() {
		return wrappedRequest.getProtocol();
	}

	public BufferedReader getReader() throws IOException {
		return wrappedRequest.getReader();
	}

	public String getRealPath(String arg0) {
		return wrappedRequest.getRealPath(arg0);
	}

	public String getRemoteAddr() {
		return wrappedRequest.getRemoteAddr();
	}

	public String getRemoteHost() {
		return wrappedRequest.getRemoteHost();
	}

	public RequestDispatcher getRequestDispatcher(String arg0) {
		//TODO patch this one for sure.
		return wrappedRequest.getRequestDispatcher(arg0);
	}

	public String getScheme() {
		return wrappedRequest.getScheme();
	}

	public String getServerName() {
		return wrappedRequest.getServerName();
	}

	public int getServerPort() {
		return wrappedRequest.getServerPort();
	}

	public boolean isSecure() {
		//TODO patch this one for sure.
		return wrappedRequest.isSecure();
	}

	public void removeAttribute(String arg0) {
		//TODO patch this one for sure.
		wrappedRequest.removeAttribute(arg0);
	}

	public void setAttribute(String arg0, Object arg1) {
		wrappedRequest.setAttribute(arg0, arg1);
	}

	public void setCharacterEncoding(String arg0) throws UnsupportedEncodingException {
		//TODO patch this one for sure.
		wrappedRequest.setCharacterEncoding(arg0);
	}
}
