
package org.apache.muse.core.platform.mini;

import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import org.apache.muse.util.xml.XmlUtils;

/**
 * 
 * @author Dan Jemiolo (danjemiolo)
 *  
 */

public class MiniServlet extends HttpServlet
{
    private static final long serialVersionUID = 685701350365490390L;
    
    //
    // the touchpoint runtime that handles all resource management
    //
    private MiniIsolationLayer _isolationLayer = null;
    
    private MiniIsolationLayer createIsolationLayer(HttpServletRequest request, ServletContext context)
    {
        MiniIsolationLayer isolationLayer = new MiniIsolationLayer(request, context);
        isolationLayer.initialize();
        return isolationLayer;
    }
    
    /**
     * 
     * POST handles all SOAP requests. The HTTP POST data is converted into 
     * a SOAP envelope and processed by MiniIsolationLayer.
     * 
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response) 
        throws IOException
    {
        if (_isolationLayer == null)
            _isolationLayer = createIsolationLayer(request, getServletContext());
            
        InputStream input = request.getInputStream();
        Document soapRequest = null;

        try
        {
            soapRequest = XmlUtils.createDocument(input);
        }

        catch (SAXException error)
        {
            throw new IOException(error.getMessage());
        }

        Document soapResponse = _isolationLayer.handleRequest(soapRequest);

        response.setContentType("text/xml");

        PrintWriter writer = response.getWriter();
        writer.write(XmlUtils.toString(soapResponse));
        writer.flush();
    }
}
