/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.tools.generator.projectizer;

import java.io.File;
import java.io.InputStream;
import java.util.Map;

import org.apache.muse.tools.generator.util.ConfigurationData;
import org.apache.muse.tools.generator.util.ConfigurationDataDescriptor;
import org.apache.muse.util.FileUtils;

/**
 * Creates a simple java project that is necessary for 
 * compiling a proxy.
 * 
 * @author Andrew Eberbach (aeberbac)
 */
public class ProxyProjectizer extends AbstractProjectizer {

	static ConfigurationDataDescriptor[] REQUIRED_PARAMETERS = 
		new ConfigurationDataDescriptor[] {
			ConfigurationData.FILES_MAP_LIST_CONFIGURATION,
			ConfigurationData.OVERWRITE_CONFIGURATION
		};
	
	protected Map[] _filesMaps;
	protected File _targetDirectory;
	
	public void projectize(ConfigurationData configuration) throws Exception {
		ConfigurationData.checkConfiguration(this, configuration);
		
		loadParameters(configuration);
		
		File libDir = new File(_targetDirectory, ProxyProjectizerConstants.LIB_DIR);
		File modulesDir = new File(System.getProperty(Axis2ProjectizerConstants.MUSE_HOME_PROPERTY),Axis2ProjectizerConstants.MODULES_DIR);
		File museLibDir = new File(System.getProperty(Axis2ProjectizerConstants.MUSE_HOME_PROPERTY),Axis2ProjectizerConstants.MUSE_LIB_DIR);
		copyJars(ProxyProjectizerConstants.REQUIRED_MODULES, modulesDir, libDir);
		copyJars(ProxyProjectizerConstants.REQUIRED_MUSE_LIBS, museLibDir, libDir);
		
		File javaSourceDir = new File(
				_targetDirectory, 
				ProxyProjectizerConstants.JAVA_SRC_DIR);
		createJavaSources(javaSourceDir, _filesMaps);
		
		createBuildFile(_targetDirectory, ProxyProjectizerConstants.BUILD_FILE_RESOURCE, ProxyProjectizerConstants.BUILD_FILE);
	}

	protected void loadParameters(ConfigurationData configuration) {
		_overwrite = ((Boolean)configuration.getParameter(ConfigurationData.OVERWRITE)).booleanValue();
		_filesMaps = (Map[])configuration.getParameter(ConfigurationData.FILES_MAP_LIST);
		_targetDirectory = (File)configuration.getParameter(ConfigurationData.TARGET_DIRECTORY);
		
		if(_targetDirectory == null) {
			_targetDirectory = FileUtils.CURRENT_DIR;
		}	
	}
	
	protected void createBuildFile(File baseTargetDir, String buildFileResource, String buildFile) throws Exception {
		InputStream buildTemplate = FileUtils.loadFromContext(this.getClass(),buildFileResource);
		File build = new File(baseTargetDir, buildFile);
		copyStreamCheck(buildTemplate, build);			
	}

	public ConfigurationDataDescriptor[] getConfigurationDataDescriptions() {
		return REQUIRED_PARAMETERS;
	}
}
