/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.tools.generator.util;

/**
 * Represents a class whose metadata can be queried. Currently, 
 * the only metadata we get out are the minimum required parameters
 * that the class is expecting.
 * 
 * This comes from the generic nature of <code>ConfigurationData</code>. Since
 * the code generation pieces (<code>Analyzer</code>, <code>Synthesizer</code>, <code>Projectizer</code>)
 * can all be swapped out and will have differing requirements, this class is a
 * way to santity check that the current part of the code generation work-flow
 * has all it needs from the previous parts and/or from the user.
 * 
 * @author Andrew Eberbach (aeberbac)
 */
public interface Configurable {
	
	/**
	 * Gets a list of elements that contain metadata about
	 * parameters used during code generation.
	 * 
	 * @return
	 * 			An array that represents the minimum necessary parameters needed
	 * 			to run this class.
	 * 
	 * @see ConfigurationData 
	 * @see org.apache.muse.tools.generator.analyzer.Analyzer
	 * @see org.apache.muse.tools.generator.synthesizer.Synthesizer
	 * @see org.apache.muse.tools.generator.projectizer.Projectizer
	 */
	ConfigurationDataDescriptor[] getConfigurationDataDescriptions();
}
