/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.util;

import java.io.PrintWriter;

/**
 *
 * Traceable is a set of operations that wish to expose optional logging 
 * as part of their operations. The interface imposes no semantics as to 
 * what is logged and when, it merely provides the mechanics for starting 
 * and stopping the logging.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Traceable
{
    /**
     * 
     * @return The trace log.
     *
     */
    public PrintWriter getTraceWriter();

    /**
     * 
     * @return True if tracing is turned on.
     *
     */
    public boolean isUsingTrace();

    /**
     * 
     * @param trace
     *        If 'true', tracing is turned on and messages sent to the trace log.
     *
     */
    public void setTrace(boolean trace);

    /**
     * 
     * @param writer
     *        The trace log - note that you can make a PrintWriter from 
     *        System.out and System.err by wrapping these fields in an 
     *        instance of PrintWriter.
     *
     */
    public void setTraceWriter(PrintWriter writer);
}
