/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import javax.xml.namespace.QName;

import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * This interface represents the WSDM CorrelatableProperties capability. 
 * Concrete implementations must maintain a collection of 
 * {@linkplain Correlation correlation expressions} which can be evaluated 
 * against any resource for the purposes of equality testing. Each correlation 
 * expression maps to an instance of the MUWS CorrelatableProperties property.
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public interface CorrelatableProperties extends ManageabilityCapability
{
    QName[] PROPERTIES = new QName[]{ 
        MuwsConstants.CORRELATABLE_QNAME
    };
    
    /**
     * 
     * @param correlation
     *        A new correlation expression that will be recorded in a new 
     *        instance of the CorrelatableProperties property.
     *
     */
    void addCorrelation(Correlation correlation)
        throws BaseFault;
    
    /**
     * 
     * @return The Correlation expressions defined in the instances of the 
     *         CorrelatableProperties property. Each Correlation can be 
     *         evaluated against a target Resource, and there is no requirement 
     *         that a caller use all Correlations to decide whether two 
     *         resources are the same.
     *         
     */
    Correlation[] getCorrelatableProperties()
        throws BaseFault;
    
    /**
     * 
     * @param epr
     *        The EPR of the resource (local or remote) to evaluate the 
     *        current correlation expressions against.
     *        
     * @return True, if all of the correlation expressions evaluated to 
     *         true when run against the given endpoint's resource properties 
     *         document.
     *         
     * @throws SoapFault
     *         <ul>
     *         <li>If there was an error when trying to contact the resource 
     *         at the given EPR, or if the endpoint does not support WS-RP.
     *         </ul>
     *
     */
    boolean matches(EndpointReference epr)
        throws SoapFault;
}
