/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 * 
 * This interface represents the WSDM ManageabilityCharacteristics capability. 
 * It provides convenience methods for accessing its one property, 
 * muws1:ManageabilityCapability. Note that the values of this property are not 
 * set by this capability but by other capabilities that are registering 
 * themselves with the resource; this capability merely provides a method for 
 * storing and reading those values.
 * 
 * @author Dan Jemiolo (danj)
 * 
 */

public interface ManageabilityCharacteristics extends ManageabilityCapability
{
    QName[] PROPERTIES = new QName[]{
        MuwsConstants.MANAGEABILITY_CAPABILITY_QNAME 
    };
    
    /**
     * 
     * @param capabilityURI
     *        A URI representing one of the manageability capabilities that 
     *        is implemented by the resource.
     *        
     * @throws BaseFault
     *         <ul>
     *         <li>If the URI has already been added to the list.</li>
     *         </ul>
     *
     */
    void addManageabilityCapability(String capabilityURI)
        throws BaseFault;
    
    /**
     * 
     * @return An array of URIs (strings), where each URI defines one 
     *         manageability capability exposed by the resource.
     *
     */
	String[] getManageabilityCapability() 
        throws BaseFault;
    
    /**
     * 
     * @param capabilityURI
     * 
     * @return True, if the URI has been added to the list of capability URIs.
     *
     */
    boolean hasManageabilityCapability(String capabilityURI) 
        throws BaseFault;
}
