/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.addressing.EndpointReference;

/**
 * 
 * Participant represents the individual resources that are named in a WSDM 
 * {@linkplain RelationshipResource relationship}. It is a sub-component of 
 * the muws2:Relationship property defined by the 
 * {@linkplain Relationships Relationships capability}.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Participant extends XmlSerializable
{
    /**
     * 
     * @return The participant's EPR.
     *
     */
    EndpointReference getManageabilityReference();

    /**
     * 
     * @return The participant's MUWS ResourceId.
     * 
     * @see org.apache.muse.ws.dm.muws.Identity#getResourceId()
     *
     */
    String getResourceId();

    /**
     * 
     * @return The URI identifying the role of the participant in its 
     *         relationship.
     *
     */
    String getRole();
}
