/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XPathUtils;
import org.apache.muse.ws.dm.muws.Correlation;
import org.apache.muse.ws.dm.muws.CorrelationFactory;
import org.apache.muse.ws.dm.muws.MuwsConstants;
import org.apache.muse.ws.resource.WsResource;

/**
 *
 * SimpleCorrelationFactory is a device for creating correlation expressions 
 * for all of the built-in dialects supported by WSDM CorrelatableProperties. 
 * Currently, the two dialects are XPath 1.0 and WSDM's Property Boolean Match.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleCorrelationFactory implements CorrelationFactory
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = 
        MessagesFactory.get(SimpleCorrelationFactory.class);
    
    public boolean hasDialect(String dialect)
    {
        return XPathUtils.NAMESPACE_URI.equals(dialect) || 
               MuwsConstants.PBM_URI.equals(dialect);
    }

    public Correlation newInstance(WsResource resource, Element xml)
    {
        if (xml == null)
            throw new NullPointerException(_MESSAGES.get("NullCPElement"));
        
        String dialect = xml.getAttribute(MuwsConstants.DIALECT);
        
        if (!hasDialect(dialect))
        {
            Object[] filler = { dialect };
            String message = _MESSAGES.get("InvalidDialect", filler);
            throw new IllegalArgumentException(message);
        }
        
        //
        // no need for a table - we only have two types
        //
        
        if (XPathUtils.NAMESPACE_URI.equals(dialect))
            return new XPathCorrelation(resource, xml);
        
        return new MatchCorrelation(resource, xml);
    }
}
