/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.dm.muws.OperationalStatus;

/**
 *
 * SimpleOperationalStatus is Muse's default implementation of the WSDM 
 * OperationalStatus capability. Validating the muws2:OperationalStatus 
 * values against the enumeration defined by WSDM is done by the WSRP 
 * implementation.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleOperationalStatus 
    extends AbstractManageabilityCapability implements OperationalStatus
{    
    private String _status = null;

    public QName[] getPropertyNames()
    {
        return PROPERTIES;
    }
    
    public void initialize()
        throws SoapFault
    {
        super.initialize();
        setOperationalStatus(UNKNOWN);
    }
    
    public String getOperationalStatus()
    {
        return _status;
    }

    public void setOperationalStatus(String status)
    {
        if (status == null)
            status = UNKNOWN;
        
        _status = status;
    }
}
