/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.dm.muws.StateType;
import org.apache.muse.ws.dm.muws.StateTransition;
import org.apache.muse.ws.dm.muws.State;

/**
 *
 * SimpleState is Muse's default implementation of the WSDM State capability.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleState 
    extends AbstractManageabilityCapability implements State
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(SimpleState.class);
        
    private StateType _state = null;
    
    private StateTransition _transition = null;

    public QName[] getPropertyNames()
    {
        return PROPERTIES;
    }
    
    public StateType getState()
    {
        return _state;
    }
    
    public StateTransition getStateTransition()
    {
        return _transition;
    }

    public void setState(StateType state)
    {
        if (state == null)
            throw new NullPointerException(_MESSAGES.get("NullState"));
        
        StateType previous = _state;
        _state = state;
        
        _transition = new SimpleStateTransition(previous, _state);
    }
}
