/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events;

import java.util.Date;

import javax.xml.namespace.QName;

import org.apache.muse.util.xml.XmlSerializable;

/**
 *
 * Situation defines the constants and fields for the WSDM Event 
 * Format's (WEF) situation data type. This type is embedded in 
 * a {@linkplain ManagementEvent ManagementEvent} when reporting 
 * events to subscribers. It is composed of accessor methods for 
 * its fields and serialization methods to convertion to and from XML. 
 * The constants define the valid values for the fields as defined 
 * by WSDM.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Situation extends XmlSerializable
{
    short LOWEST_PRIORITY = 0;
    short LOW_PRIORITY = 10;
    short MEDIUM_PRIORITY = 50;
    short HIGH_PRIORITY = 70;
    short HIGHEST_PRIORITY = 100;

    short UNKNOWN_SEVERITY = 0;
    short INFO_SEVERITY = 1;
    short WARNING_SEVERITY = 2;
    short MINOR_SEVERITY = 3;
    short MAJOR_SEVERITY = 4;
    short CRITICAL_SEVERITY = 5;
    short FATAL_SEVERITY = 6;

    String SUCCESSFUL = "Successful";

    String UNSUCCESSFUL = "Unsuccessful";
    
    QName[] getCategoryType();

    String getMessage();
    
    short getPriority();

    short getSeverity();

    Date getSituationTime();
    
    SubstitutableMessage getSubstitutableMessage();

    String getSuccessDisposition();
    
    void setCategoryType(QName categoryType);

    void setCategoryType(QName[] categoryType);

    void setMessage(String message);

    void setPriority(short priority);

    void setSeverity(short severity);

    void setSituationTime(Date situationTime);
    
    void setSubstitutableMessage(SubstitutableMessage message);

    void setSuccessDisposition(String disposition);
}
