/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events.impl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.dm.muws.events.SubstitutableMessage;
import org.apache.muse.ws.dm.muws.events.WefConstants;

/**
 * 
 * @author Dan Jemiolo (danj)
 *  
 */

public class SimpleSubstitutableMessage implements SubstitutableMessage
{
    private static final String[] _EMPTY_VALUES = new String[0];
    
    private String _msgId = null;
    
    private String _msgIdType = null;
    
    private String[] _values = _EMPTY_VALUES;

    public SimpleSubstitutableMessage()
    {
        //
        // no action - allow users to create situations from scratch
        //
    }

    public SimpleSubstitutableMessage(Element messageXML)
    {
        _msgId = messageXML.getAttribute(WefConstants.MSG_ID);
        _msgIdType = messageXML.getAttribute(WefConstants.MSG_ID_TYPE);
        _values = XmlUtils.getElementsText(messageXML, WefConstants.VALUE_QNAME);
    }

    public String getMessageId()
    {
        return _msgId;
    }

    public String getMessageIdType()
    {
        return _msgIdType;
    }

    public String[] getValues()
    {
        return _values;
    }

    public void setMessageId(String id)
    {
        _msgId = id;
    }

    public void setMessageIdType(String idType)
    {
        _msgIdType = idType;
    }

    public void setValues(String[] values)
    {
        if (values == null)
            values = _EMPTY_VALUES;
        
        _values = values;
    }

    public Element toXML()
    {
        return null;
    }

    public Element toXML(Document doc)
    {
        Element root = XmlUtils.createElement(doc, WefConstants.SUBSTITUTABLE_MSG_QNAME);
        
        root.setAttribute(WefConstants.MSG_ID, getMessageId());
        root.setAttribute(WefConstants.MSG_ID_TYPE, getMessageIdType());
        
        String[] values = getValues();
        
        for (int n = 0; n < values.length; ++n)
        {
            Element next = XmlUtils.createElement(doc, WefConstants.VALUE_QNAME, values[n]);
            root.appendChild(next);
        }
        
        return root;
    }
}
