/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events.impl;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.dm.muws.events.Component;
import org.apache.muse.ws.dm.muws.events.ComponentAddress;
import org.apache.muse.ws.dm.muws.events.ManagementEvent;
import org.apache.muse.ws.dm.muws.events.Situation;
import org.apache.muse.ws.dm.muws.events.SubstitutableMessage;
import org.apache.muse.ws.dm.muws.events.WefFactory;
import org.w3c.dom.Element;

/**
 *
 * SimpleWefFactory is the default implementation of the WefFactory component. 
 * The objects it creates are all instantiated from classes defined in this 
 * same package (org.apache.muse.ws.dm.muws.events.impl).
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleWefFactory implements WefFactory
{
    public Component createComponent()
    {
        return new SimpleComponent();
    }
    
    public Component createComponent(Element componentXML)
    {
        return new SimpleComponent(componentXML, this);
    }
    
    public ComponentAddress createComponentAddress()
    {
        return new SimpleComponentAddress();
    }
    
    public ComponentAddress createComponentAddress(Element addressXML)
    {
        return new SimpleComponentAddress(addressXML);
    }
    
    public ComponentAddress createComponentAddress(XmlSerializable addressData)
    {
        return new SimpleComponentAddress(addressData.toXML());
    }
    
    public ManagementEvent createEvent()
    {
        return new SimpleManagementEvent();
    }
    
    public ManagementEvent createEvent(Element eventXML)
    {
        return new SimpleManagementEvent(eventXML, this);
    }
    
    public Situation createSituation()
    {
        return new SimpleSituation();
    }
    
    public Situation createSituation(Element situationXML)
    {
        return new SimpleSituation(situationXML);
    }

    public SubstitutableMessage createSubstitutableMessage()
    {
        return new SimpleSubstitutableMessage();
    }

    public SubstitutableMessage createSubstitutableMessage(Element messageXML)
    {
        return new SimpleSubstitutableMessage(messageXML);
    }
}
