/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import javax.xml.namespace.QName;

/**
 *
 * WsnConstants is a collection of properties and methods that is useful when 
 * programming against the WS-Notification spec. This class uses WS-N v1.3.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WsnConstants
{
    public static final String NAMESPACE_URI = "http://docs.oasis-open.org/wsn/b-2";

    public static final String PREFIX = "wsnt";
    
    public static final String WSDL_NAMESPACE_URI = "http://docs.oasis-open.org/wsn/bw-2";
    
    public static final String WSDL_PREFIX = "wsntw";
        
    public static final String PRODUCER_URI = WSDL_NAMESPACE_URI + "/NotificationProducer";
    
    public static final String CONSUMER_URI = WSDL_NAMESPACE_URI + "/NotificationConsumer";
    
    public static final String SUBSCRIPTION_MGR_URI = WSDL_NAMESPACE_URI + "/SubscriptionManager";

    public static final String PULL_POINT_URI = WSDL_NAMESPACE_URI + "/PullPoint";
    
    public static final String PULL_POINT_CREATION_URI = WSDL_NAMESPACE_URI + "/PullPointCreation";
    
    public static final QName CONSUMER_QNAME = 
        new QName(NAMESPACE_URI, "ConsumerReference", PREFIX);
    
    public static final QName CREATION_QNAME = 
        new QName(NAMESPACE_URI, "CreationTime", PREFIX);
    
    public static final QName CURRENT_TIME_QNAME = 
        new QName(NAMESPACE_URI, "CurrentTime", PREFIX);
    
    public static final String DIALECT = "Dialect";
    
    public static final QName FILTER_QNAME = 
        new QName(NAMESPACE_URI, "Filter", PREFIX);

    public static final QName FIXED_SET_QNAME = 
        new QName(NAMESPACE_URI, "FixedTopicSet", PREFIX);

    public static final QName GET_CURRENT_QNAME = 
        new QName(NAMESPACE_URI, "GetCurrentMessage", PREFIX);
    
    public static final QName GET_CURRENT_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "GetCurrentMessageResponse", PREFIX);
    
    public static final String GET_CURRENT_URI = PRODUCER_URI + "/GetCurrentMessageRequest";
    
    public static final QName INIT_TERMINATION_TIME_QNAME = 
        new QName(NAMESPACE_URI, "TerminationTime", PREFIX);
    
    public static final QName INVALID_FILTER_QNAME = 
        new QName(NAMESPACE_URI, "InvalidFilterFault", PREFIX);
    
    public static final QName INVALID_MESSAGE_CONTENT_QNAME = 
        new QName(NAMESPACE_URI, "InvalidMessageContentExpressionFault", PREFIX);
    
    public static final QName INVALID_PRODUCER_PROPERTIES_QNAME = 
        new QName(NAMESPACE_URI, "InvalidProducerPropertiesExpressionFault", PREFIX);
    
    public static final QName INVALID_TOPIC_EXPRESSION_QNAME = 
        new QName(NAMESPACE_URI, "InvalidTopicExpressionFault", PREFIX);
    
    public static final QName MESSAGE_CONTENT_QNAME = 
        new QName(NAMESPACE_URI, "MessageContent", PREFIX);

    public static final QName MESSAGE_QNAME = 
        new QName(NAMESPACE_URI, "Message", PREFIX);

    public static final QName MULTIPLE_TOPICS_SPECIFIED_QNAME = 
        new QName(NAMESPACE_URI, "MultipleTopicsSpecifiedFault", PREFIX);

    public static final QName NO_CURRENT_MESSAGE_QNAME = 
        new QName(NAMESPACE_URI, "NoCurrentMessageOnTopicFault", PREFIX);

    public static final QName NOTIFICATION_MSG_QNAME = 
        new QName(NAMESPACE_URI, "NotificationMessage", PREFIX);

    public static final QName NOTIFY_NOT_SUPPORTED_QNAME = 
        new QName(NAMESPACE_URI, "NotifyMessageNotSupportedFault", PREFIX);

    public static final QName NOTIFY_QNAME = 
        new QName(NAMESPACE_URI, "Notify", PREFIX);

    public static final String NOTIFY_URI = CONSUMER_URI + "/NotifyRequest";

    public static final QName PAUSE_FAILED_QNAME = 
        new QName(NAMESPACE_URI, "PauseFailedFault", PREFIX);

    public static final QName PAUSE_QNAME = 
        new QName(NAMESPACE_URI, "PauseSubscription", PREFIX);

    public static final QName PAUSE_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "PauseSubscriptionResponse", PREFIX);

    public static final String PAUSE_URI = SUBSCRIPTION_MGR_URI + "/PauseSubscriptionRequest";

    public static final QName POLICY_QNAME = 
        new QName(NAMESPACE_URI, "SubscriptionPolicy", PREFIX);

    public static final QName PRODUCER_PROPERTIES_QNAME = 
        new QName(NAMESPACE_URI, "ProducerProperties", PREFIX);

    public static final QName PRODUCER_QNAME = 
        new QName(NAMESPACE_URI, "ProducerReference", PREFIX);

    public static final QName RESUME_FAILED_QNAME = 
        new QName(NAMESPACE_URI, "ResumeFailedFault", PREFIX);

    public static final QName RESUME_QNAME = 
        new QName(NAMESPACE_URI, "ResumeSubscription", PREFIX);
    
    public static final QName RESUME_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "ResumeSubscriptionResponse", PREFIX);

    public static final String RESUME_URI = SUBSCRIPTION_MGR_URI + "/ResumeSubscriptionRequest";

    public static final QName SUBSCRIBE_FAILED_QNAME = 
        new QName(NAMESPACE_URI, "SubscribeCreationFailedFault", PREFIX);

    public static final QName SUBSCRIBE_QNAME = 
        new QName(NAMESPACE_URI, "Subscribe", PREFIX);

    public static final QName SUBSCRIBE_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "SubscribeResponse", PREFIX);

    public static final String SUBSCRIBE_URI = PRODUCER_URI + "/SubscribeRequest";

    public static final QName SUBSCRIPTION_EPR_QNAME = 
        new QName(NAMESPACE_URI, "SubscriptionReference", PREFIX);

    public static final QName TERMINATION_TIME_QNAME = 
        new QName(NAMESPACE_URI, "TerminationTime", PREFIX);

    public static final QName TOPIC_DIALECT_QNAME = 
        new QName(NAMESPACE_URI, "TopicExpressionDialect", PREFIX);
    
    public static final QName TOPIC_DIALECT_UNKNOWN_QNAME = 
        new QName(NAMESPACE_URI, "TopicExpressionDialectUnknownFault", PREFIX);
    
    public static final QName TOPIC_EXPRESSION_QNAME = 
        new QName(NAMESPACE_URI, "TopicExpression", PREFIX);

    public static final QName TOPIC_NOT_SUPPORTED_QNAME = 
        new QName(NAMESPACE_URI, "TopicNotSupportedFault", PREFIX);

    public static final QName TOPIC_QNAME = 
        new QName(NAMESPACE_URI, "Topic", PREFIX);

    public static final QName UNABLE_TO_CREATE_PULL_POINT_QNAME = 
        new QName(NAMESPACE_URI, "UnableToCreatePullPointFault", PREFIX);

    public static final QName UNABLE_TO_GET_MESSAGES_QNAME = 
        new QName(NAMESPACE_URI, "UnableToGetMessagesFault", PREFIX);

    public static final QName UNACCEPTABLE_TERMINATION_TIME_QNAME = 
        new QName(NAMESPACE_URI, "UnacceptableInitialTerminationTimeFault", PREFIX);

    public static final QName UNRECOGNIZED_POLICY_QNAME = 
        new QName(NAMESPACE_URI, "UnrecognizedPolicyRequestFault", PREFIX);

    public static final QName UNSUPPORTED_POLICY_QNAME = 
        new QName(NAMESPACE_URI, "UnsupportedPolicyRequestFault", PREFIX);
}
