/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.topics;

import java.util.ListIterator;

import javax.xml.namespace.QName;

/**
 *
 * TopicPathExpression represents a qualified path that can be resolved 
 * to a topic that is published by a resource. Once the expression has 
 * been created, the resolve() method can be used to find a topic rather 
 * than searching through the resource's collection manually.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface TopicPathExpression
{
    /**
     *
     * @return That path that will be resolved by this expression.
     *
     */
    QName getTopicPath();

    /**
     *
     * @return The TopicNamespace against which the path will be resolved.
     *
     */
    TopicNamespace getTopicSpace();

    /**
     *
     * @return An iterator that allows the user to view each section of 
     *         the topic path (the strings in between each '/').
     *
     */
    ListIterator iterator();

    /**
     * 
     * Evaluates the topic path and finds the Topic it represents.
     *
     * @return The SimpleTopic that is represented by the path, or null if no 
     *         such SimpleTopic exists.
     *
     */
    Topic resolve();
}
