/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.core.serializer.Serializer;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.notification.NotificationMessage;

/**
 *
 * NotificationMessageSerializer transforms WS-N NotificationMessage objects 
 * to XML and back.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class NotificationMessageSerializer implements Serializer
{
    public Object fromXML(Element xml)
        throws SoapFault
    {
        return new SimpleNotificationMessage(xml);
    }
    
    public Class getSerializableType()
    {
        return NotificationMessage.class;
    }
    
    public Element toXML(Object obj, QName qname)
    {
        if (obj == null)
            return XmlUtils.createElement(qname);
        
        Element msgXML = ((NotificationMessage)obj).toXML();
        return XmlUtils.createElement(XmlUtils.EMPTY_DOC, qname, msgXML, false);
    }
}
