/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.properties;

import javax.xml.namespace.QName;

import org.apache.muse.ws.notification.NotificationProducer;
import org.apache.muse.ws.notification.WsnConstants;
import org.apache.muse.ws.resource.WsResource;
import org.apache.muse.ws.resource.properties.listeners.PropertyChangeListener;

/**
 *
 * WsrpNotificationListenerFactory creates instances of the 
 * {@linkplain ChangeNotificationListener ChangeNotificationListener} class. 
 * This is the default factory for WS-RP users who want to send out valid WS-RP 
 * change notifications and aren't using any other event format.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WsrpNotificationListenerFactory implements ChangeNotificationListenerFactory
{
    /**
     * 
     * @return An instance of ChangeNotificationListener.
     * 
     */
    public PropertyChangeListener newInstance(QName property, WsResource resource)
    {
        NotificationProducer wsn = (NotificationProducer)resource.getCapability(WsnConstants.PRODUCER_URI);
        return new ChangeNotificationListener(property, wsn);
    }
}
