/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.lifetime;

import org.apache.muse.ws.resource.WsResourceCapability;
import org.apache.muse.ws.resource.lifetime.faults.ResourceNotDestroyedFault;

/**
 * 
 * ImmediateTermination represents the WS-ResourceLifetime ImmediateResourceTermination 
 * capability, which has one method: wsrf-rl:Destroy. This capability allows 
 * remote clients to permanently remove resource instances from a system. If 
 * this capability is not used, only the internal application code will be 
 * allowed to destroy a resource instance.
 * 
 * @author Dan Jemiolo (danj)
 * 
 */

public interface ImmediateTermination extends WsResourceCapability
{
    /**
     * 
     * Makes the resource's destruction logic available to remote clients.
     *
     * @throws ResourceNotDestroyedFault
     *         <ul>
     *         <li>If the resource cannot be removed, or if a destruction 
     *         callback fails.</li>
     *         </ul>
     *
     */
    void destroy() 
        throws ResourceNotDestroyedFault;
}
