/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.sg;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.resource.WsResource;
import org.apache.muse.ws.resource.WsResourceCapability;
import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.addressing.EndpointReference;

/**
 *
 * Entry represents the WS-RF ServiceGroupEntry resource type. Such resources 
 * represent a relationship between a resource and the service group of which 
 * it is a member; the modification or destruction of these resources 
 * represents a change in the resource's membership in a service group. 
 * Changes in the service group members do not necessarily affect membership.
 * <br><br>
 * Muse represents all WS-SG entries at WS-RF implied resources. They 
 * are accessible through a unique endpoint and can be destroyed via WS-RL 
 * if the WS-RL capabilities are used. Adding this capability to a resource 
 * type gives it all of the required features of a WS-RF ServiceGroupEntry.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Entry extends WsResourceCapability, XmlSerializable
{
    QName[] PROPERTIES = new QName[]{
        WssgConstants.CONTENT_QNAME, 
        WssgConstants.MEMBER_EPR_QNAME, 
        WssgConstants.SG_EPR_QNAME
    };
    
    /**
     * 
     * @return The values of resource the properties (Element[]) that are 
     *         found in the service group's MembershipContentRules and which are 
     *         defined by the member service. The list may be empty if 
     *         there were no membership rules. The values returned are 
     *         <b>not</b> guaranteed to be current - they may include a 
     *         snapshot of the values from when the entry was created. If 
     *         you are unsure of the mutability of these values, you should 
     *         ask the member resource directly.
     *
     */
    Element getContent()
        throws BaseFault;
    
    /**
     * 
     * @return The EPR for the service group member this entry represents.
     * 
     */
    EndpointReference getMemberEPR()
        throws BaseFault;
    
    /**
     * 
     * @return The EPR for the service group to which this entry belongs.
     * 
     */    
    EndpointReference getServiceGroupEPR()
        throws BaseFault;
    
    /**
     * 
     * @param member
     *        A proxy for the service group member this entry represents.
     * 
     */
    void setMemberEPR(EndpointReference memberEPR)
        throws BaseFault;
    
    /**
     * 
     * @param owner
     *        A reference for the service group to which this entry belongs.
     * 
     */    
    void setServiceGroup(WsResource serviceGroup)
        throws BaseFault;
}
